importScripts('js/firebase/firebase-app-messaging.packed.js');

firebase.initializeApp({
    'messagingSenderId': '563951675713'
});

firebase.messaging().setBackgroundMessageHandler(function (payload) {
    if (!payload.data) {
        return true;
    }

    var data = {};
    try {
        data = payload.data;
    } catch (e) {
        data = {
            title: 'Received a push message',
            body: payload.data.body,
            number: 'unknown',
            name: 'unknown',
            event: 'test'
        }
    }

    console.log('Received a push message', data);

    var title = data.title;
    var tag = data.event + '-' + data.number;
    var options = {
        body: data.body,
        icon: 'collaboration/lua/avatar.lua?' + data.number + '&' + data.name,
        tag: tag,
        badge: 'collaboration/data/images/info_48.png', // img
        lang: 'en',
        requireInteraction: true,
        data: data,
        //image: 'collaboration/lua/avatar.lua?111', // show big image
        vibrate: [200, 100, 200, 100, 200, 100, 400]
    };

    return self.registration.showNotification(title, options)
        .then(function () {
            return self.registration.getNotifications();
        })
        .then(function (notifications) {
            notifications = notifications || [];
            for (var i = 0; i < notifications.length; i++) {
                if ( tag !== notifications[i].tag && (
                    notifications[i].data.event !== 'call' ||
                    (notifications[i].data.number === data.number && data.event === 'missed-call'))) {
                    notifications[i].close();
                }
            }

            return new Promise(function (resolve, reject) {
                if (data.event === 'call') {
                    setTimeout(resolve, 35 * 1000);
                }else {
                    reject();
                }
            });
        })
        .then(function () {
            return self.registration.getNotifications();
        })
        .then(function (notifications) {
            notifications = notifications || [];
            // close incoming call by timeout
            for (var i = 0; i < notifications.length; i++) {
                if (notifications[i].tag === tag && notifications[i].data.event === 'call') {
                    notifications[i].close();
                }
            }
        })
        .catch(function () {
        });
});

self.addEventListener('notificationclick', function (event) {
    // Android doesn't close the notification when you click on it
    // See: http://crbug.com/463146
    event.notification.close();

    if (event.action && (event.action === 'cancel')) {
        return;
    }

    // This looks to see if the current is already open and
    // focuses if it is
    event.waitUntil(
        clients.matchAll({
            type: "window",
            includeUncontrolled: true
        })
        .then(function (clientsList) {
            var payload = {
                channel: event.notification.data.tag,
                action: event.action
            };

            for (var i = 0; i < clientsList.length; i++) {
                var client = clientsList[i];
                if (client.url.indexOf('collaboration') >= 0 && 'focus' in client) {
                    client.postMessage(payload);

                    if (event.action !== 'reject') {
                        return client.focus();
                    }

                    return;
                }
            }
            if (clients.openWindow) {
                var window = clients.openWindow('/collaboration/');
                window.then(function (client) {
                    client.postMessage(payload);
                });

                return window;
            }
        })
    );
});