(function($){ //To-do: remove after prototype removed



    var AutoUpgradeSettings = function(data) {
        this.constructor(data);
    }

    AutoUpgradeSettings.prototype = {
        constructor: function(data) {
            this._data = {};

            this._data.autoUpgradeConfig    = data.autoUpgradeConfig;
            this._data.customFirmwareServer = data.upgradeSettings.customFirmwareServer ? data.upgradeSettings.customFirmwareServer : [];

            this.mainForm = $("#upgrade_form");
            this.mainForm.find('#upgrade_save').click($.proxy(this.save, this));

            this.mainForm.find("#autoUpgradeTable_enabled").change(function () {
                this.checkEditMode('autoUpgradeTable');
            }.bind(this));

            this.mainForm.find("#customFirmwareServer_enabled").change(function () {
                this.checkEditMode('customFirmwareServer');
            }.bind(this));

            $(window).bind('beforeunload', $.proxy(function() {
                if (this.isDirty()) {
                    return WMS._t('prefs.are_you_sure_want_to_exit_without_save');
                }
            },this));
        },
        load : function() {
            if (this._data.autoUpgradeConfig) {
                this.setUpgradeData(this._data.autoUpgradeConfig);
            }
            if (this._data.customFirmwareServer) {
                this.setCustomFirmwareServerData(this._data.customFirmwareServer);
            }
            this.checkEditMode('autoUpgradeTable');
            this.checkEditMode('customFirmwareServer');
            return this;
        },
        validate: function() {
            return this.mainForm.checkForm('validate');
        },
        getData: function() {
            var data = {
                autoUpgradeConfig: {},
                customFirmwareServer: {}
            };

            this.mainForm.find('input,select').not('[type=button]').each(
              function () {
                  var id = $(this).attr('id');
                  var category;
                  var name;
                  if (!id) {
                      return;
                  }
                  // Remove form prefix to retrive real name

                  if(id.split('autoUpgradeTable_')[1]) {
                      name  = id.split('autoUpgradeTable_')[1];
                      category = 'autoUpgradeConfig';
                  } else {
                      name  = id.split('customFirmwareServer_')[1];
                      category = 'customFirmwareServer';
                  }

                  var value = $(this).val();

                  if (name) {
                      if (['enabled', 'checkTls'].indexOf(name) > -1) {
                          value = $(this).is(':checked') ? 'yes' : 'no'
                      }
                      data[category][name] = value
                  }
              }
            )

            return data;
        },
        setUpgradeData: function(data) {
            $.each(data, $.proxy(function(name, value) {
                if (['enabled'].indexOf(name)>-1) {
                    this.mainForm.find('#autoUpgradeTable_'+name).prop('checked', value == 'yes');
                } else {
                    if (name == 'password') {
                        this.mainForm.find('#autoUpgradeTable_'+name).passwordToggler('val', value);
                    } else {
                        this.mainForm.find('#autoUpgradeTable_'+name).val(value);
                    }
                }
            },this));
        },
        setCustomFirmwareServerData: function(data) {
            $.each(data, function(name, value) {
                if (this.mainForm.find('#customFirmwareServer_' + name + '[type=checkbox]').length) {
                    this.mainForm.find('#customFirmwareServer_' + name).prop('checked', value == 'yes');
                } else {
                    this.mainForm.find('#customFirmwareServer_' + name).val(value);
                }
            }.bind(this));
        },
        isDirty: function() {
            var result = false;

            $.each(this.getData(),
              function (objName) {
                  $.each(this.getData()[objName],
                    function (name, value) {
                        if (this._data[objName][name] != value) {
                            result = true
                            return false
                        }
                    }.bind(this))
              }.bind(this));

            return result;
        },
        checkEditMode: function(table) {
            if (this.mainForm.find('#' + table + ' #' + table + '_enabled').is(':checked')) {
                this.mainForm.find('#' + table + ' input,#' + table + ' select').not('input[type=button]').not('#' + table + '_enabled').prop('disabled',false);
            } else {
                this.mainForm.find('#' + table + ' input,#' + table + ' select').not('input[type=button]').not('#' + table + '_enabled').prop('disabled',true);
            }
        },
        save: function() {

            if (this.mainForm.find('#autoUpgradeTable_enabled').is(':checked')) {

                this.mainForm.checkForm({
                    rules: [
                        "required,autoUpgradeTable_repo," + WMS._t('rules.CannotBeEmpty'),
                        "required,autoUpgradeTable_email," + WMS._t('rules.CannotBeEmpty'),
                        "valid_email,autoUpgradeTable_email," + WMS._t('rules.enterValidValue')
                    ]
                });

                if (!this.validate()) {
                    return;
                }
            }

            if (this.mainForm.find('#customFirmwareServer_enabled').is(':checked')) {

                var regExp = "^(http|https)://[a-zA-Z\\d.\\-:]{2\\,}$";
                this.mainForm.checkForm({
                    rules: [
                        "required,customFirmwareServer_url," + WMS._t('rules.CannotBeEmpty'),
                        "reg_exp,customFirmwareServer_url," + regExp + "," + WMS._t('rules.enterValidValue')
                    ]
                });

                if (!this.validate()) {
                    return;
                }
            }
            ap_showWaitMessage('waitDiv', 1);
            $.ajax({
                url: '/api/v1/PBX/settings/Upgrade/',
                type: 'POST',
                dataType: 'json',
                data: {
                    data: this.getData(),
                    _METHOD: 'PUT'
                },
                success: $.proxy(function (response) {
                    setError('success', 'Settings saved successfully', 3000);
                    if (response && response.type == 'result' && response.result) {
                        this._data = response.result;
                        this.load();
                    } else {
                        // Store to detect dirty flag in future
                        this._data = this.getData();
                    }
                },this),
                error: $.proxy(function(jqXHR) {
                    setError('error', this.parseResponseError(jqXHR) );
                },this),
                complete: function() {
                    ap_showWaitMessage('waitDiv', 0);
                }
            });
        },
        parseResponseError: function(jqXHR) {
            var error = '';
            if(jqXHR && jqXHR.responseText && jqXHR.responseText.indexOf('{') === 0) {
                var response = jQuery.parseJSON(jqXHR.responseText);
                if (response && response['reason']) {
                    error = '' + response['reason'];
                }
            }
            return error || 'Unknown error';
        }
    }

    $(document).ready(function() {
        window.us = new AutoUpgradeSettings(pageData).load();
    });


})(jQuery);
