import Vue from 'vue';
import VueRouter from 'vue-router';
import $ from 'jquery';

import Language from './pages/language/Language.vue';
import Security from './pages/security/Security.vue';
import Errors from './pages/Errors.vue';
import DHCP from './pages/dhcp/Dhcp.vue';
import Devices from './pages/devices/index.vue';
import Faxes from './pages/faxes/Faxes.vue';
import Ntp from './pages/ntp/Ntp.vue';
import Smtp from './pages/smtp/Smtp.vue';

import store from '@/store';
import AclCore from '@/modules/wms-acl';
const Acl = new AclCore(store.getters.getConfig().menu);

// for enable Vue-Devtools execute this in browser console
// localStorage.vueDevTools = true
Vue.config.devtools = (localStorage.vueDevTools === 'true' || !(process.env.NODE_ENV === 'production'));

if(!window.translation) {
    window.translation = {};
}

Vue.use(VueRouter);

let router = new VueRouter({
    linkActiveClass: 'active',
    base: '/wms',
    saveScrollPosition: true,
    history: true,
    routes: [
        {
            path: '/',
            name: 'home',
            beforeEnter() {
                if (!window.hasOwnProperty('skipRedirect')) {
                    location.href = location.origin + '?wms';
                }
            }
        },
        {
            path: '/errors',
            name: 'errors',
            component: Errors
        },
        {
            path: '/language',
            name: 'language',
            component: Language
        },
        {
            path: '/security',
            name: 'security',
            component: Security
        },
        {
            path: '/dhcp',
            name: 'dhcp',
            component: DHCP
        },
        {
            path: '/faxes',
            name: 'faxes',
            component: Faxes
        },
        {
            path: '/devices',
            name: 'devices',
            component: Devices
        },
        {
            path: '/ntp',
            name: 'ntp',
            component: Ntp
        },
        {
            path: '/smtp',
            name: 'smtp',
            component: Smtp
        }
    ]
});

router.beforeEach((to, from, next) => {
    if (
        ['errors', 'home'].indexOf(to.name) === -1 &&
        !Acl.has(to.name)
    ) {
        next('/errors');
    } else {
        next();
    }
});

router.afterEach((to) => {
    // TODO ::after refactor remove with jq
    $('ul.menu li').removeClass('active');
    $("ul.menu li[data-spa-route='" + to.name + "']").addClass('active');
    $("ul#mmenu-1 li[data-menu-name='settings']").addClass('active');

    setCurrentPage(to);
});

function setCurrentPage(targetPage) {
    let config = store.getters.getConfig();
    for(let id in config.menu) {
        if (config.menu.hasOwnProperty(id) && config.menu[id].route === targetPage.name) {
            router.currentPageConfig = config.menu[id];
            if (config.menu[id].title) {
                document.title = config.title + ' ' + config.menu[id].title;
            }
        }
    }
}

export default router;
